(function() {
    'use strict';

    angular
        .module('app')
        .controller('AppController', AppController);

    AppController.$inject = ['Modal'];

    /* @ngInject */
    function AppController(Modal) {
        var vm = this;
        vm.showModal = showModal;
        vm.formModal = formModal;
        vm.formResourceModal = formResourceModal;
        vm.formWithFileModal = formWithFileModal;
        vm.formModalKeepOpen = formModalKeepOpen;
        vm.formModalOtherFunc = formModalOtherFunc;

        function showModal() {
            var attr = {
                templateUrl: 'templates/index.html',
                title: 'This is a title',
                first_name: 'Rej',
                last_name: 'Mediodia'
            };

            var modal = Modal.open(attr);
        }

        function formModal() {
            var attr = {
                templateUrl: 'templates/form.html',
                title : 'Form Modal',
                url : 'server/sample.php', // url to be save accepting post method
                input : {
                    first_name : 'Rej',
                    last_name : 'Mediodia'
                }
            }

            var modal = Modal.open(attr);

            modal.then(function (result) {
                // when saved or close if keepOpen
                console.log('returned data',result);
            }, function () {
                // when closed
            });
        }

        function formResourceModal() {
            var attr = {
                templateUrl: 'templates/form.html',
                title : 'Form Resource Modal',
                resource : {
                    service : 'App',
                    action : 'save'
                },
                input : {
                    first_name : 'Rej',
                    last_name : 'Mediodia'
                }
            }

            var modal = Modal.open(attr);

            modal.then(function (result) {
                // when saved or close if keepOpen
                console.log('returned data',result);
            }, function () {
                // when closed
            });
        }

        function formWithFileModal() {
            var attr = {
                templateUrl: 'templates/form-file.html',
                title : 'Form with file Modal',
                url : 'server/sample-with-file.php',
            }

            var modal = Modal.open(attr);

            modal.then(function (result) {
                // when saved or close if keepOpen
                console.log('returned data',result);
            }, function () {
                // when closed
            });
        }

        function formModalKeepOpen() {
            var attr = {
                templateUrl: 'templates/form.html',
                title : 'Form Modal Keep Open',
                url : 'server/sample.php',
                keepOpen: true,
                input : {
                    first_name : 'Rej',
                    last_name : 'Mediodia',
                }
            }

            var modal = Modal.open(attr);

            modal.then(function (result) {
                // when saved or close if keepOpen
                console.log('returned data',result);
            }, function () {
                // when closed
            });
        }

        function formModalOtherFunc() {
            var attr = {
                templateUrl: 'templates/other-form.html',
                title : 'Form Modal Other Functions',
                url : 'server/sample.php',
                input : {
                    first_name : 'Rej',
                    last_name : 'Mediodia',
                },
                otherFunc : otherFunc
            }

            var modal = Modal.open(attr);

            modal.then(function (result) {
                // when saved or close if keepOpen
                console.log('returned data',result);
            }, function () {
                // when closed
            });
        }

        function otherFunc() {
            console.log('other function');
        }

        // END OF FUNCTIONS

        //SCRIPTS TO DISPLAY
        vm.javascript = (
            "function AppController(Modal) {\n" +
            "    var vm = this;\n" +
            "    vm.showModal = showModal;\n" +
            "    function showModal() {\n" +
            "        var attr = {\n" +
            "            templateUrl: 'templates/index.html',\n" +
            "            title: 'This is a title',\n" +
            "            first_name: 'Rej',\n" +
            "            last_name: 'Mediodia'\n" +
            "        };\n" +
            "\n" +
            "        var modal = Modal.open(attr);\n" +
            "}"
        );
        vm.html = (
          '<div> class = "col-md-12" ng-controller = "AppController as ac"</div>\n' +
          '  <button class = "btn btn-default" ng-click = "ac.showModal()">Click Me!</button>\n' +
          '</div>'
        );
        vm.modal = (
            '<div class="modal-header">\n' +
            '  <h3 class="modal-title">{{ dmic.title }}</h3>\n' +
            '</div>\n' +
            '<div class="modal-body">\n' +
            '  <h2>Modal Body</h2>\n' +
            '  <div class ="form-group">\n' +
            '    <div class = "row">\n' +
            '      <label class = "col-md-4">First Name</label>\n' +
            '      <label class = "col-md-8" ng-bind ="dmic.first_name"></label>\n' +
            '    </div>\n' +
            '  </div>\n' +
            '  <div class ="form-group">\n' +
            '    <div class = "row">\n' +
            '      <label class = "col-md-4">Last Name</label>\n' +
            '      <label class = "col-md-8" ng-bind ="dmic.last_name"></label>\n' +
            '    </div>\n' +
            '  </div>\n' +
            '</div>\n' +
            '<div class="modal-footer">\n' +
            '  <button class="btn btn-warning" type="button" ng-click="dmic.close()">Close</button>\n'+
            '</div>'
        );

        vm.javascriptForm = (
            "function AppController(Modal) {\n" +
            "    var vm = this;\n" +
            "    vm.formModal = formModal;\n" +
            "    function formModal() {\n" +
            "        var attr = {\n" +
            "            templateUrl: 'templates/form.html',\n" +
            "            title : 'Form Modal',\n" +
            "            url : 'server/sample.php', // url to be save accepting post method\n" +
            "            input : {\n" +
            "                first_name : 'Rej',\n" +
            "                last_name : 'Mediodia'\n" +
            "            }\n" +
            "        };\n" +
            "\n" +
            "        var modal = Modal.open(attr);\n" +
            "        modal.then(function (result) {\n" +
            "            // when saved or close if keepOpen\n" +
            "            console.log('returned data',result);\n" +
            "        }, function () {\n" +
            "            // when closed\n" +
            "        });\n" +
            "}"
        );
        vm.htmlForm = (
          '<div> class = "col-md-12" ng-controller = "AppController as ac"</div>\n' +
          '  <button class = "btn btn-default" ng-click = "ac.formModal()">Click Me!</button>\n' +
          '</div>'
        );
        vm.modalForm = (
            '<div class="modal-header">\n' +
            '  <h3 class="modal-title">{{ dmic.title }}</h3>\n' +
            '</div>\n' +
            '<div class = "row" ng-if = "dmic.message" >\n' +
            '  <div class = "col-md-12">\n' +
            '    <h3 class="bg-warning" style = "text-align:center">{{dmic.message}}</h3>\n'+
            '  </div>\n' +
            '</div>\n' +
            '<div class="modal-body">\n' +
            '  <h2>Modal Body</h2>\n' +
            '  <div class ="form-group">\n' +
            '    <div class = "row">\n' +
            '      <label class = "col-md-4">First Name</label>\n' +
            '      <div class = "col-md-8">\n' +
            '         <input type = "text" ng-model = "dmic.input.first_name">\n' +
            '      </div>\n' +
            '    </div>\n' +
            '  </div>\n' +
            '  <div class ="form-group">\n' +
            '    <div class = "row">\n' +
            '      <label class = "col-md-4">Last Name</label>\n' +
            '      <div class = "col-md-8">\n' +
            '         <input type = "text" ng-model = "dmic.input.last_name">\n' +
            '      </div>\n' +
            '    </div>\n' +
            '  </div>\n' +
            '</div>\n' +
            '<div class="modal-footer">\n' +
            '  <button class="btn btn-primary" type="button" ng-click="dmic.save()">Save</button>\n' +
            '  <button class="btn btn-warning" type="button" ng-click="dmic.close()">Close</button>\n'+
            '</div>'
        );

        vm.javascriptREST = (
            "function AppController(Modal) {\n" +
            "    var vm = this;\n" +
            "    vm.formResourceModal = formResourceModal;\n" +
            "    function formResourceModal() {\n" +
            "        var attr = {\n" +
            "            templateUrl: 'templates/form.html',\n" +
            "            title : 'Form Resource Modal',\n" +
            "            resource : {\n" +
            "                service : 'App', // the name of the service\n" +
            "                action : 'save' // the action of the service to be used\n" +
            "            },\n" +
            "            input : {\n" +
            "                first_name : 'Rej',\n" +
            "                last_name : 'Mediodia'\n" +
            "            }\n" +
            "        };\n" +
            "\n" +
            "        var modal = Modal.open(attr);\n" +
            "        modal.then(function (result) {\n" +
            "            // when saved or close if keepOpen\n" +
            "            console.log('returned data',result);\n" +
            "        }, function () {\n" +
            "            // when closed\n" +
            "        });\n" +
            "}"
        );
        vm.htmlREST = (
          '<div> class = "col-md-12" ng-controller = "AppController as ac"</div>\n' +
          '  <button class = "btn btn-default" ng-click = "ac.formResourceModal()">Click Me!</button>\n' +
          '</div>'
        );

        vm.javascriptFile = (
            "function AppController(Modal) {\n" +
            "    var vm = this;\n" +
            "    vm.formWithFileModal = formWithFileModal;\n" +
            "    function formWithFileModal() {\n" +
            "        var attr = {\n" +
            "            templateUrl: 'templates/index.html',\n" +
            "            title : 'Form with file Modal',\n" +
            "            url : 'server/sample-with-file.php', // url to be save accepting post method\n" +
            "        };\n" +
            "\n" +
            "        var modal = Modal.open(attr);\n" +
            "        modal.then(function (result) {\n" +
            "            // when saved or close if keepOpen\n" +
            "            console.log('returned data',result);\n" +
            "        }, function () {\n" +
            "            // when closed\n" +
            "        });\n" +
            "}"
        );
        vm.htmlFile = (
          '<div> class = "col-md-12" ng-controller = "AppController as ac"</div>\n' +
          '  <button class = "btn btn-default" ng-click = "ac.formWithFileModal()">Click Me!</button>\n' +
          '</div>'
        );
        vm.modalFile = (
            '<div class="modal-header">\n' +
            '  <h3 class="modal-title">{{ dmic.title }}</h3>\n' +
            '</div>\n' +
            '<div class = "row" ng-if = "dmic.message" >\n' +
            '  <div class = "col-md-12">\n' +
            '    <h3 class="bg-warning" style = "text-align:center">{{dmic.message}}</h3>\n'+
            '  </div>\n' +
            '</div>\n' +
            '<div class="modal-body">\n' +
            '  <h2>Modal Body</h2>\n' +
            '  <div class ="form-group">\n' +
            '    <div class = "row">\n' +
            '      <label class = "col-md-4">First Name</label>\n' +
            '      <div class = "col-md-8">\n' +
            '         <input type = "text" ng-model = "dmic.input.first_name">\n' +
            '      </div>\n' +
            '    </div>\n' +
            '  </div>\n' +
            '  <div class ="form-group">\n' +
            '    <div class = "row">\n' +
            '      <label class = "col-md-4">Last Name</label>\n' +
            '      <div class = "col-md-8">\n' +
            '         <input type = "text" ng-model = "dmic.input.last_name">\n' +
            '      </div>\n' +
            '    </div>\n' +
            '  </div>\n' +
            '  <div class ="form-group">\n' +
            '    <div class = "row">\n' +
            '      <label class = "col-md-4">Upload File</label>\n' +
            '      <div class = "col-md-8">\n' +
            '        <input type = "file" file-read = "dmic.input.file" >\n' +
            '      </div>\n' +
            '    </div>\n' +
            '  </div>\n'+
            '</div>\n' +
            '<div class="modal-footer">\n' +
            '  <button class="btn btn-primary" type="button" ng-click="dmic.saveWithFile()">Save</button>\n' +
            '  <button class="btn btn-warning" type="button" ng-click="dmic.close()">Close</button>\n'+
            '</div>'
        );

        vm.javascriptOpen = (
            "function AppController(Modal) {\n" +
            "    var vm = this;\n" +
            "    vm.formModalKeepOpen = formModalKeepOpen;\n" +
            "    function formModalKeepOpen() {\n" +
            "        var attr = {\n" +
            "            templateUrl: 'templates/form.html',\n" +
            "            title : 'Form Modal Keep Open',\n" +
            "            url : 'server/sample.php', // url to be save accepting post method\n" +
            "            keepOpen: true,\n" +
            "            input : {\n" +
            "                first_name : 'Rej',\n" +
            "                last_name : 'Mediodia'\n" +
            "            }\n" +
            "        };\n" +
            "\n" +
            "        var modal = Modal.open(attr);\n" +
            "        modal.then(function (result) {\n" +
            "            // when saved or close if keepOpen\n" +
            "            console.log('returned data',result);\n" +
            "        }, function () {\n" +
            "            // when closed\n" +
            "        });\n" +
            "}"
        );
        vm.htmlOpen = (
          '<div> class = "col-md-12" ng-controller = "AppController as ac"</div>\n' +
          '  <button class = "btn btn-default" ng-click = "ac.formModalKeepOpen()">Click Me!</button>\n' +
          '</div>'
        );

        vm.javascriptOther = (
            "function AppController(Modal) {\n" +
            "    var vm = this;\n" +
            "    vm.formModalOtherFunc = formModalOtherFunc;\n" +
            "    function formModalOtherFunc() {\n" +
            "        var attr = {\n" +
            "            templateUrl: 'templates/other-form.html',\n" +
            "            title : 'Form Modal Other Functions',\n" +
            "            url : 'server/sample.php', // url to be save accepting post method\n" +
            "            keepOpen: true,\n" +
            "            input : {\n" +
            "                first_name : 'Rej',\n" +
            "                last_name : 'Mediodia'\n" +
            "            },\n" +
            "            otherFunc : otherFunc\n" +
            "        };\n" +
            "\n" +
            "        var modal = Modal.open(attr);\n" +
            "        modal.then(function (result) {\n" +
            "            // when saved or close if keepOpen\n" +
            "            console.log('returned data',result);\n" +
            "        }, function () {\n" +
            "            // when closed\n" +
            "        });\n" +
            "}\n" +
            "function otherFunc() {\n" +
            "   console.log('other Function');\n" +
            "}"
        );
        vm.htmlOther = (
          '<div> class = "col-md-12" ng-controller = "AppController as ac"</div>\n' +
          '  <button class = "btn btn-default" ng-click = "ac.formModalOtherFunc()">Click Me!</button>\n' +
          '</div>'
        );
        vm.modalOther = (
            '<div class="modal-header">\n' +
            '  <h3 class="modal-title">{{ dmic.title }}</h3>\n' +
            '</div>\n' +
            '<div class = "row" ng-if = "dmic.message" >\n' +
            '  <div class = "col-md-12">\n' +
            '    <h3 class="bg-warning" style = "text-align:center">{{dmic.message}}</h3>\n'+
            '  </div>\n' +
            '</div>\n' +
            '<div class="modal-body">\n' +
            '  <h2>Modal Body</h2>\n' +
            '  <div class ="form-group">\n' +
            '    <div class = "row">\n' +
            '      <label class = "col-md-4">First Name</label>\n' +
            '      <div class = "col-md-8">\n' +
            '         <input type = "text" ng-model = "dmic.input.first_name">\n' +
            '      </div>\n' +
            '    </div>\n' +
            '  </div>\n' +
            '  <div class ="form-group">\n' +
            '    <div class = "row">\n' +
            '      <label class = "col-md-4">Last Name</label>\n' +
            '      <div class = "col-md-8">\n' +
            '         <input type = "text" ng-model = "dmic.input.last_name">\n' +
            '      </div>\n' +
            '    </div>\n' +
            '  </div>\n' +
            '</div>\n' +
            '<div class="modal-footer">\n' +
            '  <button class="btn btn-danger" type="button" ng-click="dmic.otherFunc()">Other Func</button>\n' +
            '  <button class="btn btn-primary" type="button" ng-click="dmic.save()">Save</button>\n' +
            '  <button class="btn btn-warning" type="button" ng-click="dmic.close()">Close</button>\n'+
            '</div>'
        );

    }
})();
